@@ -82,7 +82,7 @@ class History(Model):
     path = CodeStrictField()
     username = NameField()
     fio = NameField()
-    data = JSONFieldIVC(default=dict)
+    data = JSONFieldIVC()
     ip_address = GenericIPAddressField()
     user_agent = TextField()
 
