@@ -11,7 +11,7 @@ class Usergroup_permission(AuditModel):
 
     usergroup = ForeignKeyCascade("UserGroup")
     widget = ForeignKeyCascade("Widgets_trees")
-    permission = JSONFieldIVC(default=dict)
+    permission = JSONFieldIVC()
 
     # def __str__(self):
     #     return f"{self.code}: {self.name}"
