@@ -2,7 +2,7 @@ import datetime
 
 
 def DateToStr(date, mask='%d.%m.%Y', hours=3):
-    if date == None:
+    if date is None:
         return None
     if isinstance(date, str):
         date = StrToDate(date)
@@ -10,7 +10,7 @@ def DateToStr(date, mask='%d.%m.%Y', hours=3):
 
 
 def DateTimeToStr(date, mask='%d.%m.%Y %H:%M:%S', hours=0):
-    if date == None:
+    if date is None:
         return None
     if isinstance(date, str):
         date = StrToDate(date)
@@ -82,7 +82,7 @@ def manth_name(month):
 # %%	A literal '%' character.	%
 
 def StrToDate(value_str, mask='%Y-%m-%dT%H:%M:%S', hours=0):
-    if value_str == None:
+    if value_str is None:
         return None
 
     if isinstance(value_str, datetime.date):
